netapp_ontap.models.cluster_nodes_ha_ports API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_ha_ports`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesHaPortsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesHaPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `number: Size GET`

    HA port number

    Example: 0

  `state: str GET`

    HA port state:

    - down - Logical HA link is down.
    - initialized - Logical HA link is initialized. The physical link is up, but the subnet manager hasn't started to configure the port.
    - armed - Logical HA link is armed. The physical link is up and the subnet manager started but did not yet complete configuring the port.
    - active - Logical HA link is active.
    - reserved - Logical HA link is active, but the physical link is down.

    Valid choices:

    - down
    - initialized
    - armed
    - active
    - reserved